#[repr(u32)]pub enum cublasFillMode_t {
CUBLAS_FILL_MODE_LOWER = 0,
CUBLAS_FILL_MODE_UPPER = 1,
CUBLAS_FILL_MODE_FULL = 2,
}Expand description
The type indicates which part (lower or upper) of the dense matrix was filled and consequently should be used by the function.
Notice that BLAS implementations often use Fortran characters ‘L’ or ‘l’ (lower) and ‘U’ or ‘u’ (upper) to describe which part of the matrix is filled.
Variants
CUBLAS_FILL_MODE_LOWER = 0
The lower part of the matrix is filled.
CUBLAS_FILL_MODE_UPPER = 1
The upper part of the matrix is filled.
CUBLAS_FILL_MODE_FULL = 2
The full matrix is filled.