cusolverAlgMode_t

Enum cusolverAlgMode_t 

#[repr(u32)]
pub enum cusolverAlgMode_t { CUSOLVER_ALG_0 = 0, CUSOLVER_ALG_1 = 1, CUSOLVER_ALG_2 = 2, }
The cusolverAlgMode_t type indicates which algorithm is selected by cusolverDnSetAdvOptions. The set of algorithms supported for each routine is described in detail along with the routine’s documentation.

The default algorithm is cusolverAlgMode_t::CUSOLVER_ALG_0. The user can also provide NULL to use the default algorithm.

Variants



CUSOLVER_ALG_0 = 0



CUSOLVER_ALG_1 = 1



CUSOLVER_ALG_2 = 2