#[repr(u32)]pub enum cusolverEigType_t {
CUSOLVER_EIG_TYPE_1 = 1,
CUSOLVER_EIG_TYPE_2 = 2,
CUSOLVER_EIG_TYPE_3 = 3,
}Expand description
The cusolverEigType_t type indicates which type of eigenvalue the solver is.
Notice that LAPACK implementations often use Fortran integer 1 (A*x = lambda*B*x), 2 (A*B*x = lambda*x), 3 (B*A*x = lambda*x) to indicate which type of eigenvalue the solver is.
Variants
CUSOLVER_EIG_TYPE_1 = 1
A*x = lambda*B*x.
CUSOLVER_EIG_TYPE_2 = 2
A*B*x = lambda*x.
CUSOLVER_EIG_TYPE_3 = 3
B*A*x = lambda*x.