cusolverDnCpotrs

Function cusolverDnCpotrs 

pub unsafe extern "C" fn cusolverDnCpotrs(
    handle: cusolverDnHandle_t,
    uplo: cublasFillMode_t,
    n: c_int,
    nrhs: c_int,
    A: *const cuComplex,
    lda: c_int,
    B: *mut cuComplex,
    ldb: c_int,
    devInfo: *mut c_int,
) -> cusolverStatus_t
This function solves a system of linear equations: $$ A\*X = B $$

where A is an $n \times n$ Hermitian matrix, only lower or upper part is meaningful. The input parameter uplo indicates which part of the matrix is used. The function will leave the other part untouched.

The user has to call potrf first to factorize matrix A. If input parameter uplo is cublasFillMode_t::CUBLAS_FILL_MODE_LOWER, A is lower triangular Cholesky factor L corresponding to $A = L\*L^H$. If input parameter uplo is cublasFillMode_t::CUBLAS_FILL_MODE_UPPER, A is upper triangular Cholesky factor U corresponding to $A = U^{H}\*U$.

The operation is in-place, i.e. matrix X overwrites matrix B with the same leading dimension ldb.

If output parameter devInfo = -i (less than zero), the i-th parameter is wrong (not counting handle).