cusolverDnCreate

Function cusolverDnCreate 

pub unsafe extern "C" fn cusolverDnCreate(
    handle: *mut cusolverDnHandle_t,
) -> cusolverStatus_t
This function initializes the cuSolverDN library and creates a handle on the cuSolverDN context. It must be called before any other cuSolverDN API function is invoked. It allocates hardware resources necessary for accessing the GPU. This function allocates 4 MiB or 32 MiB of memory (for GPUs with Compute Capability of 9.0 and higher), which will be used as the cuBLAS workspace for the first user-defined stream on which cusolverDnSetStream is called. For the default stream and in all the other cases, cuBLAS will manage its own workspace.

Parameters

  • handle: The pointer to the handle to the cuSolverDN context.

Return value