cusolverDnDorgtr

Function cusolverDnDorgtr 

pub unsafe extern "C" fn cusolverDnDorgtr(
    handle: cusolverDnHandle_t,
    uplo: cublasFillMode_t,
    n: c_int,
    A: *mut f64,
    lda: c_int,
    tau: *const f64,
    work: *mut f64,
    lwork: c_int,
    info: *mut c_int,
) -> cusolverStatus_t
These helper functions calculate the size of work buffers needed.

The S and D data types are real valued single and double precision, respectively.

The C and Z data types are complex valued single and double precision, respectively.

This function generates a unitary matrix Q which is defined as the product of n-1 elementary reflectors of order n, as returned by sytrd:

The user has to provide working space which is pointed by input parameter work. The input parameter lwork is size of the working space, and it is returned by orgtr_bufferSize(). Please note that the size in bytes of the working space is equal to sizeof(<type>) * lwork.

If output parameter devInfo = -i (less than zero), the i-th parameter is wrong (not counting handle).