cusolverDnGetEmulationStrategy

Function cusolverDnGetEmulationStrategy 

pub unsafe extern "C" fn cusolverDnGetEmulationStrategy(
    handle: cusolverDnHandle_t,
    strategy: *mut cudaEmulationStrategy_t,
) -> cusolverStatus_t
This function queries the emulation strategy which is set for handle.

The emulation strategy returned by this API only has an effect, once one of the following math modes is enabled (see also cusolverMathMode_t):

cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The strategy was queried successfully.

cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The library was not initialized.

cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE: emulationStrategy is a NULL pointer.

Parameters

  • handle: Handle to the cuSolverDN library context.
  • strategy: The emulation strategy of handle.

Return value