cusolverDnGetFixedPointEmulationMantissaBitOffset

Function cusolverDnGetFixedPointEmulationMantissaBitOffset 

pub unsafe extern "C" fn cusolverDnGetFixedPointEmulationMantissaBitOffset(
    handle: cusolverDnHandle_t,
    mantissaBitOffset: *mut c_int,
) -> cusolverStatus_t
This function queries the mantissa bit offset for fixed point FP64 emulation in case of dynamic mantissa control mode.

The mantissa bit offset, which is returned by this API only has an effect, once one of the following math modes is enabled (see also cusolverMathMode_t):

And the following mantissa control is enabled (see also cusolverDnSetFixedPointEmulationMantissaControl):

  • CUDA_EMULATION_MANTISSA_CONTROL_DYNAMIC

Please note that values of mantissaBitOffset which are unequal to zero require the mantissa control to be equal to CUDA_EMULATION_MANTISSA_CONTROL_DYNAMIC. Otherwise, the computational cuSOLVER routines will return cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE, indicating an unsupported handle state.

Parameters

  • handle: Handle to the cuSolverDN library context.
  • mantissaBitOffset: The mantissa bit offset used when CUDA_EMULATION_MANTISSA_CONTROL_DYNAMIC is in use.

Return value