pub unsafe extern "C" fn cusolverDnGetFixedPointEmulationMaxMantissaBitCount(
handle: cusolverDnHandle_t,
mantissaBitCount: *mut c_int,
) -> cusolverStatus_tExpand description
This function queries the maximum number of mantissa bits used for fixed point FP64 emulation.
The mantissa bit count returned by this API only has an effect, once one of the following math modes is enabled (see also cusolverMathMode_t):
cusolverMathMode_t::CUSOLVER_FP64_EMULATED_FIXEDPOINT_MATHcusolverMathMode_t::CUSOLVER_FP32_FP64_EMULATED_MATH.
Parameters
handle: Handle to the cuSolverDN library context.mantissaBitCount: The maximum number of mantissa bits used.
Return value
cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE:mantissaBitCountis aNULLpointer.cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The library was not initialized.cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The mantissa bit count was queried successfully.