cusolverDnIRSInfosCreate

Function cusolverDnIRSInfosCreate 

pub unsafe extern "C" fn cusolverDnIRSInfosCreate(
    infos_ptr: *mut cusolverDnIRSInfos_t,
) -> cusolverStatus_t
This function creates and initializes the Infos structure that will hold the refinement information of an Iterative Refinement Solver (IRS) call. Such information includes the total number of iterations that was needed to converge (Niters), the outer number of iterations (meaningful when two-levels preconditioner such as cusolverIRSRefinement_t::CUSOLVER_IRS_REFINE_CLASSICAL_GMRES is used ), the maximal number of iterations that was allowed for that call, and a pointer to the matrix of the convergence history residual norms. The Infos structure needs to be created before a call to an IRS solver. The Infos structure is valid for only one call to an IRS solver, since it holds info about that solve and thus each solve will requires its own Infos structure.

Return value