cusolverDnIRSInfosDestroy

Function cusolverDnIRSInfosDestroy 

pub unsafe extern "C" fn cusolverDnIRSInfosDestroy(
    infos: cusolverDnIRSInfos_t,
) -> cusolverStatus_t
This function destroys and releases any memory required by the Infos structure. This function destroys all the information (for example, Niters performed, OuterNiters performed, residual history etc.) about a solver call; thus, this function should only be called after the user is finished with the information.

Return value