cusolverDnIRSInfosGetMaxIters

Function cusolverDnIRSInfosGetMaxIters 

pub unsafe extern "C" fn cusolverDnIRSInfosGetMaxIters(
    infos: cusolverDnIRSInfos_t,
    maxiters: *mut cusolver_int_t,
) -> cusolverStatus_t
This function returns the maximal allowed number of iterations that was set for the corresponding call to the IRS solver. Note that this function returns the setting that was set when that call happened and is not to be confused with the cusolverDnIRSParamsGetMaxIters which returns the current setting in the params configuration structure. To be clearer, the params structure can be used for many calls to an IRS solver. A user can change the allowed MaxIters between calls while the Infos structure in cusolverDnIRSInfosGetMaxIters contains information about a particular call and cannot be reused for different calls, thus cusolverDnIRSInfosGetMaxIters returns the allowed MaxIters for that call.

Parameters

  • infos: The cusolverDnIRSInfos_t Infos structure.
  • maxiters: The maximal number of iterations that is currently set.

Return value