cusolverDnIRSInfosGetNiters

Function cusolverDnIRSInfosGetNiters 

pub unsafe extern "C" fn cusolverDnIRSInfosGetNiters(
    infos: cusolverDnIRSInfos_t,
    niters: *mut cusolver_int_t,
) -> cusolverStatus_t
This function returns the total number of iterations performed by the IRS solver. If it was negative, it means that the IRS solver did not converge and if the user did not disable the fallback to full precision, then the fallback to a full precision solution happened and solution is good. Please refer to the description of negative niters values in the corresponding IRS linear solver functions such as cusolverDnXgesv() or cusolverDnXgels().

Parameters

  • infos: The cusolverDnIRSInfos_t Infos structure.
  • niters: The total number of iterations performed by the IRS solver.

Return value