cusolverDnIRSInfosGetOuterNiters

Function cusolverDnIRSInfosGetOuterNiters 

pub unsafe extern "C" fn cusolverDnIRSInfosGetOuterNiters(
    infos: cusolverDnIRSInfos_t,
    outer_niters: *mut cusolver_int_t,
) -> cusolverStatus_t
This function returns the number of iterations performed by the outer refinement loop of the IRS solver. When the refinement solver consists of a one-level solver such as cusolverIRSRefinement_t::CUSOLVER_IRS_REFINE_CLASSICAL or cusolverIRSRefinement_t::CUSOLVER_IRS_REFINE_GMRES, it is the same as Niters. When the refinement solver consists of a two-levels solver such as cusolverIRSRefinement_t::CUSOLVER_IRS_REFINE_CLASSICAL_GMRES or cusolverIRSRefinement_t::CUSOLVER_IRS_REFINE_GMRES_GMRES, it is the number of iterations of the outer loop. Refer to the description of the cusolverIRSRefinement_t for more details.

Parameters

  • infos: The cusolverDnIRSInfos_t Infos structure.
  • outer_niters: The number of iterations of the outer refinement loop of the IRS solver.

Return value