cusolverDnIRSInfosRequestResidual

Function cusolverDnIRSInfosRequestResidual 

pub unsafe extern "C" fn cusolverDnIRSInfosRequestResidual(
    infos: cusolverDnIRSInfos_t,
) -> cusolverStatus_t
This function tells the IRS solver to store the convergence history (residual norms) of the refinement phase in a matrix that can be accessed via a pointer returned by the cusolverDnIRSInfosGetResidualHistory function.

Parameters

  • infos: The cusolverDnIRSInfos_t Infos structure.

Return value