cusolverDnIRSParamsDisableFallback

Function cusolverDnIRSParamsDisableFallback 

pub unsafe extern "C" fn cusolverDnIRSParamsDisableFallback(
    params: cusolverDnIRSParams_t,
) -> cusolverStatus_t
This function disables the fallback to the main precision in case the Iterative Refinement Solver (IRS) failed to converge. In other term, if the IRS solver failed to converge, the solver will return a no convergence code (e.g., niter < 0), but can either return the non-convergent solution as it is (e.g., disable fallback) or can fallback (e.g., enable fallback) to the main precision (which is the precision of the Inputs/Outputs data) and solve the problem from scratch returning the good solution. This function disables the fallback and the returned solution is whatever the refinement solver was able to reach before it returns. Disabling fallback does not guarantee that the solution is the good one. However, if users want to keep getting the solution of the lower precision in case the IRS did not converge after certain number of iterations, they need to disable the fallback. The user can re-enable it by calling cusolverDnIRSParamsEnableFallback.

Parameters

  • params: The cusolverDnIRSParams_t Params structure.

Return value