cusolverDnIRSParamsSetMaxItersInner

Function cusolverDnIRSParamsSetMaxItersInner 

pub unsafe extern "C" fn cusolverDnIRSParamsSetMaxItersInner(
    params: cusolverDnIRSParams_t,
    maxiters_inner: cusolver_int_t,
) -> cusolverStatus_t
This function sets the maximal number of iterations allowed for the inner refinement solver. It is not referenced in case of one level refinement solver such as cusolverIRSRefinement_t::CUSOLVER_IRS_REFINE_CLASSICAL or cusolverIRSRefinement_t::CUSOLVER_IRS_REFINE_GMRES. The inner refinement solver will stop after reaching either the inner tolerance or the MaxItersInner value. By default, it is set to 50. Note that this value could not be larger than the MaxIters since MaxIters is the total number of allowed iterations. Note that if the user calls cusolverDnIRSParamsSetMaxIters after calling this function, SetMaxIters has priority and will overwrite MaxItersInner to the minimum value of (MaxIters, MaxItersInner).

Parameters

Return value