cusolverDnIRSParamsSetSolverMainPrecision

Function cusolverDnIRSParamsSetSolverMainPrecision 

pub unsafe extern "C" fn cusolverDnIRSParamsSetSolverMainPrecision(
    params: cusolverDnIRSParams_t,
    solver_main_precision: cusolverPrecType_t,
) -> cusolverStatus_t
This function sets the main precision for the Iterative Refinement Solver (IRS). By main precision, we mean, the type of the Input and Output data. Note that the user has to set both the main and lowest precision before a first call to the IRS solver because they are NOT set by default with the params structure creation, as it depends on the Input Output data type and user request. user can set it by either calling this function or by calling cusolverDnIRSParamsSetSolverPrecisions which set both the main and the lowest precision together. All possible combinations of main/lowest precision are described in the table in the cusolverDnIRSParamsSetSolverPrecisions section above.

Parameters

  • params: The cusolverDnIRSParams_t Params structure.
  • solver_main_precision: Allowed Inputs/Outputs datatype (for example CUSOLVER_R_FP64 for a real double precision data). See the table in the cusolverDnIRSParamsSetSolverPrecisions section above for the supported precisions.

Return value