cusolverDnIRSParamsSetTol

Function cusolverDnIRSParamsSetTol 

pub unsafe extern "C" fn cusolverDnIRSParamsSetTol(
    params: cusolverDnIRSParams_t,
    val: f64,
) -> cusolverStatus_t
This function sets the tolerance for the refinement solver. By default it is such that all the RHS satisfy:

RNRM < SQRT(N)XNRMANRMEPSBWDMAX where

  • RNRM is the infinity-norm of the residual
  • XNRM is the infinity-norm of the solution
  • ANRM is the infinity-operator-norm of the matrix A
  • EPS is the machine epsilon for the Inputs/Outputs datatype that matches LAPACK <X>LAMCH(‘Epsilon’)
  • BWDMAX, the value BWDMAX is fixed to 1.0

The user can use this function to change the tolerance to a lower or higher value. Our goal is to give the user more control such a way he can investigate and control every detail of the IRS solver. Note that the tolerance value is always in real double precision whatever the Inputs/Outputs datatype is.

Parameters

  • params: The cusolverDnIRSParams_t Params structure.
  • val: Double precision real value to which the refinement tolerance will be set.

Return value