pub unsafe extern "C" fn cusolverDnLoggerSetLevel(
level: c_int,
) -> cusolverStatus_tExpand description
This function sets the value of the logging level.
See cusolverStatus_t for a complete list of valid return codes.
Parameters
level: Value of the logging level. See cuSOLVERDn Logging.
Return value
cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE: If the value was not a valid logging level. See cuSOLVERDn Logging.cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: If the logging level was successfully set.