cusolverDnSetEmulationSpecialValuesSupport

Function cusolverDnSetEmulationSpecialValuesSupport 

pub unsafe extern "C" fn cusolverDnSetEmulationSpecialValuesSupport(
    handle: cusolverDnHandle_t,
    mask: cudaEmulationSpecialValuesSupport_t,
) -> cusolverStatus_t
This function sets the handling of special floating point values for handle, which is used once floating point emulation is allowed.

The special value support set by this API only has an effect, once one of the following math modes is enabled (see also cusolverMathMode_t):

cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The special value support was set successfully.

cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The library was not initialized.

cusolverStatus_t::CUSOLVER_STATUS_INTERNAL_ERROR: An internal error occurred.

Parameters

  • handle: Handle to the cuSolverDN library context.
  • mask: If set to CUDA_EMULATION_SPECIAL_VALUE_SUPPORT_DEFAULT, values are propagated as expected. Performance of floating point emulated math may improve if set to CUDA_EMULATION_SPECIAL_VALUES_SUPPORT_NONE for which the propagation of special values is undefined.

Return value