cusolverDnSetEmulationStrategy

Function cusolverDnSetEmulationStrategy 

pub unsafe extern "C" fn cusolverDnSetEmulationStrategy(
    handle: cusolverDnHandle_t,
    strategy: cudaEmulationStrategy_t,
) -> cusolverStatus_t
This function sets the emulation strategy of all cuSolverDN functions for handle. For more information about the effects of the corresponding strategies, please refer to the analogous definition of cublasEmulationStrategy_t.

The emulation strategy set by this API only has an effect, once one of the following math modes is enabled (see also cusolverMathMode_t):

Parameters

  • handle: Handle to the cuSolverDN library context.
  • strategy: The emulation strategy to be used with handle.

Return value