cusolverDnSetFixedPointEmulationMaxMantissaBitCount

Function cusolverDnSetFixedPointEmulationMaxMantissaBitCount 

pub unsafe extern "C" fn cusolverDnSetFixedPointEmulationMaxMantissaBitCount(
    handle: cusolverDnHandle_t,
    mantissaBitCount: c_int,
) -> cusolverStatus_t
This function sets the maximum number of mantissa bits for fixed point FP64 emulation.

The maximum mantissa bit count set by this API only has an effect, once one of the following math modes is enabled (see also cusolverMathMode_t):

cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The mantissa bit count was set successfully.

cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The library was not initialized.

cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE: mantissaBitCount is less than 0.

cusolverStatus_t::CUSOLVER_STATUS_INTERNAL_ERROR: An internal error occurred.

Parameters

  • handle: Handle to the cuSolverDN library context.
  • mantissaBitCount: The number of mantissa bits to be used. Setting mantissaBitCount = 0 resets to the default configuration as described in cuBLAS defaults.

Return value