pub unsafe extern "C" fn cusolverDnSetMathMode(
handle: cusolverDnHandle_t,
mode: cusolverMathMode_t,
) -> cusolverStatus_tExpand description
This function sets the math modes of all cuSolverDN functions for handle. For more information about the effects of the corresponding math modes, please refer to cusolverMathMode_t. Note that math modes can be combined, e.g., cusolverDnSetMathMode(handle, CUSOLVER_FP32_EMULATED_BF16X9_MATH | CUSOLVER_FP64_EMULATED_FIXEDPOINT_MATH). Please see cusolverMathMode_t for allowed combinations.
Parameters
handle: Handle to the cuSolverDN library context.
Return value
cusolverStatus_t::CUSOLVER_STATUS_INTERNAL_ERROR: An internal error occurred.cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE: An invalid mode was given.cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The library was not initialized.cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The mode was set successfully.