pub unsafe extern "C" fn cusolverDnSorgbr(
handle: cusolverDnHandle_t,
side: cublasSideMode_t,
m: c_int,
n: c_int,
k: c_int,
A: *mut f32,
lda: c_int,
tau: *const f32,
work: *mut f32,
lwork: c_int,
info: *mut c_int,
) -> cusolverStatus_tExpand description
These helper functions calculate the size of work buffers needed.
The S and D data types are real valued single and double precision, respectively.
The C and Z data types are complex valued single and double precision, respectively.
This function generates one of the unitary matrices Q or P**H determined by gebrd when reducing a matrix A to bidiagonal form: $Q^{H}\*A\*P = B$
Q and P**H are defined as products of elementary reflectors H(i) or G(i) respectively.
The user has to provide working space which is pointed by input parameter work. The input parameter lwork is size of the working space, and it is returned by orgbr_bufferSize(). Please note that the size in bytes of the working space is equal to sizeof(<type>) * lwork.
If output parameter devInfo = -i (less than zero), the i-th parameter is wrong (not counting handle).