cusolverDnHandle_t

Type Alias cusolverDnHandle_t 

pub type cusolverDnHandle_t = *mut cusolverDnContext;
This is a pointer type to an opaque cuSolverDN context, which the user must initialize by calling cusolverDnCreate prior to calling any other library function. An uninitialized Handle object will lead to unexpected behavior, including crashes of cuSolverDN. The handle created and returned by cusolverDnCreate must be passed to every cuSolverDN function.