cusolverDnIRSInfos_t

Type Alias cusolverDnIRSInfos_t 

pub type cusolverDnIRSInfos_t = *mut cusolverDnIRSInfos;
This is a pointer type to an opaque cusolverDnIRSInfos_t structure, which holds information about the performed call to an iterative refinement linear solver (such as cusolverDnXgesv()). Use corresponding helper functions described below to either Create/Destroy this structure or retrieve solve information.