cusolverDnIRSParams_t

Type Alias cusolverDnIRSParams_t 

pub type cusolverDnIRSParams_t = *mut cusolverDnIRSParams;
This is a pointer type to an opaque cusolverDnIRSParams_t structure, which holds parameters for the iterative refinement linear solvers such as cusolverDnXgesv(). Use corresponding helper functions described below to either Create/Destroy this structure or Set/Get solver parameters.