cusolverStatus_t

Enum cusolverStatus_t 

#[repr(u32)]
pub enum cusolverStatus_t {
Show 25 variants CUSOLVER_STATUS_SUCCESS = 0, CUSOLVER_STATUS_NOT_INITIALIZED = 1, CUSOLVER_STATUS_ALLOC_FAILED = 2, CUSOLVER_STATUS_INVALID_VALUE = 3, CUSOLVER_STATUS_ARCH_MISMATCH = 4, CUSOLVER_STATUS_MAPPING_ERROR = 5, CUSOLVER_STATUS_EXECUTION_FAILED = 6, CUSOLVER_STATUS_INTERNAL_ERROR = 7, CUSOLVER_STATUS_MATRIX_TYPE_NOT_SUPPORTED = 8, CUSOLVER_STATUS_NOT_SUPPORTED = 9, CUSOLVER_STATUS_ZERO_PIVOT = 10, CUSOLVER_STATUS_INVALID_LICENSE = 11, CUSOLVER_STATUS_IRS_PARAMS_NOT_INITIALIZED = 12, CUSOLVER_STATUS_IRS_PARAMS_INVALID = 13, CUSOLVER_STATUS_IRS_PARAMS_INVALID_PREC = 14, CUSOLVER_STATUS_IRS_PARAMS_INVALID_REFINE = 15, CUSOLVER_STATUS_IRS_PARAMS_INVALID_MAXITER = 16, CUSOLVER_STATUS_IRS_INTERNAL_ERROR = 20, CUSOLVER_STATUS_IRS_NOT_SUPPORTED = 21, CUSOLVER_STATUS_IRS_OUT_OF_RANGE = 22, CUSOLVER_STATUS_IRS_NRHS_NOT_SUPPORTED_FOR_REFINE_GMRES = 23, CUSOLVER_STATUS_IRS_INFOS_NOT_INITIALIZED = 25, CUSOLVER_STATUS_IRS_INFOS_NOT_DESTROYED = 26, CUSOLVER_STATUS_IRS_MATRIX_SINGULAR = 30, CUSOLVER_STATUS_INVALID_WORKSPACE = 31,
}
This is a status type returned by the library functions and it can have the following values.

cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The operation completed successfully.

cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The cuSolver library was not initialized. This is usually caused by the lack of a prior call, an error in the CUDA Runtime API called by the cuSolver routine, or an error in the hardware setup.

To correct: call cusolverDnCreate prior to the function call; and check that the hardware, an appropriate version of the driver, and the cuSolver library are correctly installed.

cusolverStatus_t::CUSOLVER_STATUS_ALLOC_FAILED: Resource allocation failed inside the cuSolver library. This is usually caused by a cudaMalloc() failure.

To correct: prior to the function call, deallocate previously allocated memory as much as possible.

cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE: An unsupported value or parameter was passed to the function (a negative vector size, for example).

To correct: ensure that all the parameters being passed have valid values.

cusolverStatus_t::CUSOLVER_STATUS_ARCH_MISMATCH: The function requires a feature absent from the device architecture; usually caused by the lack of support for atomic operations or double precision.

To correct: compile and run the application on a device with compute capability 5.0 or above.

cusolverStatus_t::CUSOLVER_STATUS_EXECUTION_FAILED: The GPU program failed to execute. This is often caused by a launch failure of the kernel on the GPU, which can be caused by multiple reasons.

To correct: check that the hardware, an appropriate version of the driver, and the cuSolver library are correctly installed.

cusolverStatus_t::CUSOLVER_STATUS_INTERNAL_ERROR: An internal cuSolver operation failed. This error is usually caused by a cudaMemcpyAsync() failure.

To correct: check that the hardware, an appropriate version of the driver, and the cuSolver library are correctly installed. Also, check that the memory passed as a parameter to the routine is not being deallocated prior to the routine’s completion.

cusolverStatus_t::CUSOLVER_STATUS_MATRIX_TYPE_NOT_SUPPORTED: The matrix type is not supported by this function. This is usually caused by passing an invalid matrix descriptor to the function.

To correct: check that the fields in descrA were set correctly.

cusolverStatus_t::CUSOLVER_STATUS_NOT_SUPPORTED: The parameter combination is not supported, for example batched version is not supported or M < N is not supported.

To correct: consult the documentation, and use a supported configuration.

Variants



CUSOLVER_STATUS_SUCCESS = 0

The operation completed successfully.



CUSOLVER_STATUS_NOT_INITIALIZED = 1

The cuSolver library was not initialized. This is usually caused by the lack of a prior call, an error in the CUDA Runtime API called by the cuSolver routine, or an error in the hardware setup.

To correct: call cusolverDnCreate prior to the function call; and check that the hardware, an appropriate version of the driver, and the cuSolver library are correctly installed.



CUSOLVER_STATUS_ALLOC_FAILED = 2

Resource allocation failed inside the cuSolver library. This is usually caused by a cudaMalloc() failure.

To correct: prior to the function call, deallocate previously allocated memory as much as possible.



CUSOLVER_STATUS_INVALID_VALUE = 3

An unsupported value or parameter was passed to the function (a negative vector size, for example).

To correct: ensure that all the parameters being passed have valid values.



CUSOLVER_STATUS_ARCH_MISMATCH = 4

The function requires a feature absent from the device architecture; usually caused by the lack of support for atomic operations or double precision.

To correct: compile and run the application on a device with compute capability 5.0 or above.



CUSOLVER_STATUS_MAPPING_ERROR = 5



CUSOLVER_STATUS_EXECUTION_FAILED = 6

The GPU program failed to execute. This is often caused by a launch failure of the kernel on the GPU, which can be caused by multiple reasons.

To correct: check that the hardware, an appropriate version of the driver, and the cuSolver library are correctly installed.



CUSOLVER_STATUS_INTERNAL_ERROR = 7

An internal cuSolver operation failed. This error is usually caused by a cudaMemcpyAsync() failure.

To correct: check that the hardware, an appropriate version of the driver, and the cuSolver library are correctly installed. Also, check that the memory passed as a parameter to the routine is not being deallocated prior to the routine’s completion.



CUSOLVER_STATUS_MATRIX_TYPE_NOT_SUPPORTED = 8

The matrix type is not supported by this function. This is usually caused by passing an invalid matrix descriptor to the function.

To correct: check that the fields in descrA were set correctly.



CUSOLVER_STATUS_NOT_SUPPORTED = 9

The parameter combination is not supported, for example batched version is not supported or M < N is not supported.

To correct: consult the documentation, and use a supported configuration.



CUSOLVER_STATUS_ZERO_PIVOT = 10



CUSOLVER_STATUS_INVALID_LICENSE = 11



CUSOLVER_STATUS_IRS_PARAMS_NOT_INITIALIZED = 12



CUSOLVER_STATUS_IRS_PARAMS_INVALID = 13



CUSOLVER_STATUS_IRS_PARAMS_INVALID_PREC = 14



CUSOLVER_STATUS_IRS_PARAMS_INVALID_REFINE = 15



CUSOLVER_STATUS_IRS_PARAMS_INVALID_MAXITER = 16



CUSOLVER_STATUS_IRS_INTERNAL_ERROR = 20



CUSOLVER_STATUS_IRS_NOT_SUPPORTED = 21



CUSOLVER_STATUS_IRS_OUT_OF_RANGE = 22



CUSOLVER_STATUS_IRS_NRHS_NOT_SUPPORTED_FOR_REFINE_GMRES = 23



CUSOLVER_STATUS_IRS_INFOS_NOT_INITIALIZED = 25



CUSOLVER_STATUS_IRS_INFOS_NOT_DESTROYED = 26



CUSOLVER_STATUS_IRS_MATRIX_SINGULAR = 30



CUSOLVER_STATUS_INVALID_WORKSPACE = 31