pub unsafe extern "C" fn cusolverDnGetEmulationSpecialValuesSupport(
handle: cusolverDnHandle_t,
mask: *mut cudaEmulationSpecialValuesSupport_t,
) -> cusolverStatus_tExpand description
This function queries the special floating point value support which is set for handle if floating point emulation is allowed.
The special floating point value support returned by this API only has an effect, once one of the following math modes is enabled (see also cusolverMathMode_t):
cusolverMathMode_t::CUSOLVER_FP32_EMULATED_BF16X9_MATHcusolverMathMode_t::CUSOLVER_FP64_EMULATED_FIXEDPOINT_MATHcusolverMathMode_t::CUSOLVER_FP32_FP64_EMULATED_MATH
Otherwise, special floating point values are handled as expected.
cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The special value handling was queried successfully.
cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The library was not initialized.
cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE: mask is a NULL pointer.
Parameters
handle: Handle to the cuSolverDN library context.mask: The special value support ofhandle. Please see cudaEmulationSpecialValuesSupport_t for more information about the allowed values ofmask.
Return value
cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE:maskis aNULLpointer.cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The library was not initialized.cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The special value handling was queried successfully.