pub unsafe extern "C" fn cusolverDnGetEmulationStrategy(
handle: cusolverDnHandle_t,
strategy: *mut cudaEmulationStrategy_t,
) -> cusolverStatus_tExpand description
This function queries the emulation strategy which is set for handle.
The emulation strategy returned by this API only has an effect, once one of the following math modes is enabled (see also cusolverMathMode_t):
cusolverMathMode_t::CUSOLVER_FP32_EMULATED_BF16X9_MATHcusolverMathMode_t::CUSOLVER_FP64_EMULATED_FIXEDPOINT_MATHcusolverMathMode_t::CUSOLVER_FP32_FP64_EMULATED_MATH.
Parameters
handle: Handle to the cuSolverDN library context.strategy: The emulation strategy ofhandle.
Return value
cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE:emulationStrategyis aNULLpointer.cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The library was not initialized.cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The strategy was queried successfully.