cusolverDnGetFixedPointEmulationMantissaControl

Function cusolverDnGetFixedPointEmulationMantissaControl 

pub unsafe extern "C" fn cusolverDnGetFixedPointEmulationMantissaControl(
    handle: cusolverDnHandle_t,
    control: *mut cudaEmulationMantissaControl_t,
) -> cusolverStatus_t
This function queries how the number of mantissa bits is determined for fixed point FP64 emulation.

The mantissa control returned by this API only has an effect, once one of the following math modes is enabled (see also cusolverMathMode_t):

cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The mantissa control was queried successfully.

cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The library was not initialized.

cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE: control is a NULL pointer.

Parameters

  • handle: Handle to the cuSolverDN library context.
  • control: The mantissa control mode of handle.

Return value