pub unsafe extern "C" fn cusolverDnGetFixedPointEmulationMantissaControl(
handle: cusolverDnHandle_t,
control: *mut cudaEmulationMantissaControl_t,
) -> cusolverStatus_tExpand description
This function queries how the number of mantissa bits is determined for fixed point FP64 emulation.
The mantissa control returned by this API only has an effect, once one of the following math modes is enabled (see also cusolverMathMode_t):
cusolverMathMode_t::CUSOLVER_FP64_EMULATED_FIXEDPOINT_MATHcusolverMathMode_t::CUSOLVER_FP32_FP64_EMULATED_MATH
cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The mantissa control was queried successfully.
cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The library was not initialized.
cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE: control is a NULL pointer.
Parameters
handle: Handle to the cuSolverDN library context.control: The mantissa control mode ofhandle.
Return value
cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE:controlis aNULLpointer.cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The library was not initialized.cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The mantissa control was queried successfully.