pub unsafe extern "C" fn cusolverDnIRSInfosDestroy(
infos: cusolverDnIRSInfos_t,
) -> cusolverStatus_tExpand description
This function destroys and releases any memory required by the Infos structure. This function destroys all the information (for example, Niters performed, OuterNiters performed, residual history etc.) about a solver call; thus, this function should only be called after the user is finished with the information.
Return value
cusolverStatus_t::CUSOLVER_STATUS_IRS_INFOS_NOT_INITIALIZED: TheInfosstructure was not created.cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The resources were released successfully.