pub unsafe extern "C" fn cusolverDnIRSInfosGetNiters(
infos: cusolverDnIRSInfos_t,
niters: *mut cusolver_int_t,
) -> cusolverStatus_tExpand description
This function returns the total number of iterations performed by the IRS solver. If it was negative, it means that the IRS solver did not converge and if the user did not disable the fallback to full precision, then the fallback to a full precision solution happened and solution is good. Please refer to the description of negative niters values in the corresponding IRS linear solver functions such as cusolverDnXgesv() or cusolverDnXgels().
Parameters
infos: ThecusolverDnIRSInfos_t Infosstructure.niters: The total number of iterations performed by the IRS solver.
Return value
cusolverStatus_t::CUSOLVER_STATUS_IRS_INFOS_NOT_INITIALIZED: TheInfosstructure was not created.cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The operation completed successfully.