pub unsafe extern "C" fn cusolverDnIRSInfosGetOuterNiters(
infos: cusolverDnIRSInfos_t,
outer_niters: *mut cusolver_int_t,
) -> cusolverStatus_tExpand description
This function returns the number of iterations performed by the outer refinement loop of the IRS solver. When the refinement solver consists of a one-level solver such as cusolverIRSRefinement_t::CUSOLVER_IRS_REFINE_CLASSICAL or cusolverIRSRefinement_t::CUSOLVER_IRS_REFINE_GMRES, it is the same as Niters. When the refinement solver consists of a two-levels solver such as cusolverIRSRefinement_t::CUSOLVER_IRS_REFINE_CLASSICAL_GMRES or cusolverIRSRefinement_t::CUSOLVER_IRS_REFINE_GMRES_GMRES, it is the number of iterations of the outer loop. Refer to the description of the cusolverIRSRefinement_t for more details.
Parameters
infos: ThecusolverDnIRSInfos_t Infosstructure.outer_niters: The number of iterations of the outer refinement loop of the IRS solver.
Return value
cusolverStatus_t::CUSOLVER_STATUS_IRS_INFOS_NOT_INITIALIZED: TheInfosstructure was not created.cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The operation completed successfully.