pub unsafe extern "C" fn cusolverDnIRSInfosRequestResidual(
infos: cusolverDnIRSInfos_t,
) -> cusolverStatus_tExpand description
This function tells the IRS solver to store the convergence history (residual norms) of the refinement phase in a matrix that can be accessed via a pointer returned by the cusolverDnIRSInfosGetResidualHistory function.
Parameters
infos: ThecusolverDnIRSInfos_t Infosstructure.
Return value
cusolverStatus_t::CUSOLVER_STATUS_IRS_INFOS_NOT_INITIALIZED: TheInfosstructure was not created.cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The operation completed successfully.