pub unsafe extern "C" fn cusolverDnIRSParamsCreate(
params_ptr: *mut cusolverDnIRSParams_t,
) -> cusolverStatus_tExpand description
This function creates and initializes the structure of parameters for an IRS solver such as the cusolverDnIRSXgesv or the cusolverDnIRSXgels functions to default values. The params structure created by this function can be used by one or more call to the same or to a different IRS solver. Note that in CUDA 10.2, the behavior was different and a new params structure was needed to be created per each call to an IRS solver. Also note that the user can also change configurations of the params and then call a new IRS instance, but be careful that the previous call was done because any change to the configuration before the previous call was done could affect it.
Return value
cusolverStatus_t::CUSOLVER_STATUS_ALLOC_FAILED: The resources could not be allocated.cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The structure was created and initialized successfully.