pub unsafe extern "C" fn cusolverDnIRSParamsSetMaxIters(
params: cusolverDnIRSParams_t,
maxiters: cusolver_int_t,
) -> cusolverStatus_tExpand description
This function sets the total number of allowed refinement iterations after which the solver will stop. Total means any iteration which means the sum of the outer and the inner iterations (inner is meaningful when two-levels refinement solver is set). Default value is set to 50. Our goal is to give the user more control such a way he can investigate and control every detail of the IRS solver.
Parameters
params: ThecusolverDnIRSParams_t Paramsstructure.
Return value
cusolverStatus_t::CUSOLVER_STATUS_IRS_PARAMS_NOT_INITIALIZED: TheParamsstructure was not created.cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The operation completed successfully.