pub unsafe extern "C" fn cusolverDnIRSParamsSetSolverMainPrecision(
params: cusolverDnIRSParams_t,
solver_main_precision: cusolverPrecType_t,
) -> cusolverStatus_tExpand description
This function sets the main precision for the Iterative Refinement Solver (IRS). By main precision, we mean, the type of the Input and Output data. Note that the user has to set both the main and lowest precision before a first call to the IRS solver because they are NOT set by default with the params structure creation, as it depends on the Input Output data type and user request. user can set it by either calling this function or by calling cusolverDnIRSParamsSetSolverPrecisions which set both the main and the lowest precision together. All possible combinations of main/lowest precision are described in the table in the cusolverDnIRSParamsSetSolverPrecisions section above.
cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The operation completed successfully.
cusolverStatus_t::CUSOLVER_STATUS_IRS_PARAMS_NOT_INITIALIZED: The Params structure was not created.
Parameters
params: ThecusolverDnIRSParams_t Paramsstructure.solver_main_precision: Allowed Inputs/Outputs datatype (for example CUSOLVER_R_FP64 for a real double precision data). See the table in thecusolverDnIRSParamsSetSolverPrecisionssection above for the supported precisions.
Return value
cusolverStatus_t::CUSOLVER_STATUS_IRS_PARAMS_NOT_INITIALIZED: TheParamsstructure was not created.cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The operation completed successfully.