pub unsafe extern "C" fn cusolverDnLoggerOpenFile(
logFile: *const c_char,
) -> cusolverStatus_tExpand description
This function opens a logging output file in the given path.
cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: If the logging file was successfully opened.
See cusolverStatus_t for a complete list of valid return codes.
Parameters
logFile: Path of the logging output file.
Return value
cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: If the logging file was successfully opened.