pub unsafe extern "C" fn cusolverDnLoggerSetFile(
file: *mut FILE,
) -> cusolverStatus_tExpand description
This function sets the logging output file. Note: once registered using this function call, the provided file handle must not be closed unless the function is called again to switch to a different file handle.
cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: If logging file was successfully set.
See cusolverStatus_t for a complete list of valid return codes.
Parameters
file: Pointer to an open file. File should have write permission.
Return value
cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: If logging file was successfully set.