cusolverDnLoggerSetLevel

Function cusolverDnLoggerSetLevel 

pub unsafe extern "C" fn cusolverDnLoggerSetLevel(
    level: c_int,
) -> cusolverStatus_t
This function sets the value of the logging level.

cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE: If the value was not a valid logging level. See cuSOLVERDn Logging.

cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: If the logging level was successfully set.

See cusolverStatus_t for a complete list of valid return codes.

Parameters

  • level: Value of the logging level. See cuSOLVERDn Logging.

Return value