pub unsafe extern "C" fn cusolverDnLoggerSetMask(
mask: c_int,
) -> cusolverStatus_tExpand description
This function sets the value of the logging mask.
cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: If the logging mask was successfully set.
See cusolverStatus_t for a complete list of valid return codes.
Parameters
mask: Value of the logging mask. See cuSOLVERDn Logging.
Return value
cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: If the logging mask was successfully set.