cusolverDnSetEmulationStrategy

Function cusolverDnSetEmulationStrategy 

pub unsafe extern "C" fn cusolverDnSetEmulationStrategy(
    handle: cusolverDnHandle_t,
    strategy: cudaEmulationStrategy_t,
) -> cusolverStatus_t
This function sets the emulation strategy of all cuSolverDN functions for handle. For more information about the effects of the corresponding strategies, please refer to the analogous definition of cublasEmulationStrategy_t.

The emulation strategy set by this API only has an effect, once one of the following math modes is enabled (see also cusolverMathMode_t):

cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The strategy was set successfully.

cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The library was not initialized.

cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE: strategy was not a supported emulation strategy

cusolverStatus_t::CUSOLVER_STATUS_INTERNAL_ERROR: An internal error occurred.

Parameters

  • handle: Handle to the cuSolverDN library context.
  • strategy: The emulation strategy to be used with handle.

Return value