cusolverDnSetFixedPointEmulationMantissaControl

Function cusolverDnSetFixedPointEmulationMantissaControl 

pub unsafe extern "C" fn cusolverDnSetFixedPointEmulationMantissaControl(
    handle: cusolverDnHandle_t,
    control: cudaEmulationMantissaControl_t,
) -> cusolverStatus_t
This function sets how the number of mantissa bits is determined for fixed point FP64 emulation. For more information about the effects of the corresponding control modes, please refer to cudaEmulationMantissaControl_t.

The mantissa control set by this API only has an effect, once one of the following math modes is enabled (see also cusolverMathMode_t):

cusolverStatus_t::CUSOLVER_STATUS_SUCCESS: The mantissa control was set successfully.

cusolverStatus_t::CUSOLVER_STATUS_NOT_INITIALIZED: The library was not initialized.

cusolverStatus_t::CUSOLVER_STATUS_INVALID_VALUE: control is not a valid cudaEmulationMantissaControl_t value.

cusolverStatus_t::CUSOLVER_STATUS_INTERNAL_ERROR: An internal error occurred.

Parameters

  • handle: Handle to the cuSolverDN library context.
  • control: The mantissa control mode to be used with handle.

Return value